#!/usr/bin/python3

# Nemo Media Columns

from setuptools import setup

# Setup stage
setup( packages=[],
    name         = "nemo-media-columns",
    version      = "6.6.0",
    description  = "Column provider for nemo to show additional metadata for media and image files",
    author       = "Linux Mint",
    author_email = "root@linuxmint.com",
    url          = "https://github.com/linuxmint/nemo-extensions",
    license      = "GPL3",

    # See debian/control for install-depends - this is useless here, except as reference.
    # install_requires (and only works with python modules.  It's equally as bad to have
    # some deps here, then draw them into debian/control using {python3:Depends} and add
    # them to our non-python depends.

    # install_requires = ['gir1.2-nemo-3.0 >=3.8',
    #                     'python-nemo >=3.8',
    #                     'gir1.2-gexiv2-0.10',
    #                     'mutagen',
    #                     'pypdf',
    #                     'pil',
    #                     'pymediainfo'
    #                     'stopit'],
    data_files   = [
        ('/usr/share/nemo-python/extensions', ['nemo-media-columns.py']),
        ('/usr/bin',                          ['nemo-media-columns-prefs']),
        ('/usr/share/glib-2.0/schemas',       ['org.nemo.extensions.nemo-media-columns.gschema.xml'])
    ]
)



#!/usr/bin/python3

import gi
gi.require_version('Gtk', '3.0')
gi.require_version('XApp', '1.0')
import sys

import gettext
from gi.repository import Gtk, Gio, XApp, Gdk

# i18n
import gettext
gettext.bindtextdomain('nemo-extensions')
gettext.textdomain('nemo-extensions')
_ = gettext.gettext


class LabeledItem(Gtk.Box):
    def __init__(self, label, item):
        super(LabeledItem, self).__init__(orientation=Gtk.Orientation.HORIZONTAL)

        self.label_widget = Gtk.Label(label)

        self.pack_start(self.label_widget, False, False, 6)
        self.pack_end(item, False, False, 6)

        self.show_all()

class Page(Gtk.Box):
    def __init__(self):
        super(Page, self).__init__(orientation=Gtk.Orientation.VERTICAL)

        self.set_spacing(15)
        self.set_margin_start(15)
        self.set_margin_end(15)
        self.set_margin_top(15)
        self.set_margin_bottom(15)

class NemoTerminalPreferencesWindow(XApp.PreferencesWindow):
    def __init__(self):
        super(NemoTerminalPreferencesWindow, self).__init__()

        self.set_icon_name("terminal")
        self.set_title(_("Nemo-Terminal Preferences"))
        self.set_skip_taskbar_hint(False)
        self.set_type_hint(Gdk.WindowTypeHint.NORMAL)
        self.set_default_size(-1, -1)

        self.connect("destroy", Gtk.main_quit)

        self.settings = Gio.Settings(schema_id="org.nemo.extensions.nemo-terminal")

        # Basic

        page = Page()

        frame = Gtk.Frame()
        frame.get_style_context().add_class("view")

        page.add(frame)

        box = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
        frame.add(box)

        switch = Gtk.Switch()
        self.settings.bind("default-visible",
                           switch, "active",
                           Gio.SettingsBindFlags.DEFAULT)

        widget = LabeledItem(_("Visible by default"), switch)
        box.pack_start(widget, False, False, 6)

        combo = Gtk.ComboBoxText()
        combo.append("top", _("Top"))
        combo.append("bottom", _("Bottom"))
        self.settings.bind("terminal-position",
                           combo, "active-id",
                           Gio.SettingsBindFlags.DEFAULT)

        widget = LabeledItem(_("Terminal position"), combo)
        box.pack_start(widget, False, False, 6)

        combo = Gtk.ComboBoxText()
        combo.append("None", _("Independent"))
        combo.append("Terminal follows Nemo", _("Terminal follows view location"))
        # combo.append("Nemo follows Terminal", _("View follows terminal location"))
        # combo.append("Nemo and Terminal Synchronized", _("Keep locations synchronized"))
        self.settings.bind("default-follow-mode",
                           combo, "active-id",
                           Gio.SettingsBindFlags.DEFAULT)

        widget = LabeledItem(_("Location mode"), combo)
        box.pack_start(widget, False, False, 6)

        switch = Gtk.Switch()
        self.settings.bind("audible-bell",
                           switch, "active",
                           Gio.SettingsBindFlags.DEFAULT)

        widget = LabeledItem(_("Terminal bell"), switch)
        box.pack_start(widget, False, False, 6)

        spinner = Gtk.SpinButton.new_with_range(5, 1000, 1)
        spinner.set_digits(0)
        self.settings.bind("default-terminal-height",
                           spinner, "value",
                           Gio.SettingsBindFlags.DEFAULT)

        widget = LabeledItem(_("Default number of lines for the terminal"), spinner)
        box.pack_start(widget, False, False, 6)

        frame = Gtk.Frame()
        treeview = Gtk.TreeView(headers_visible=False, enable_search=False, hover_selection=True)
        cell = Gtk.CellRendererAccel(editable=True,
                                     accel_mode=Gtk.CellRendererAccelMode.GTK,
                                     width=140, xalign=0.5, yalign=0.5)

        col = Gtk.TreeViewColumn("binding", cell, accel_key=0, accel_mods=1)
        treeview.append_column(col)

        store = Gtk.ListStore(int, Gdk.ModifierType)
        treeview.set_model(store)

        def update_accel_from_settings(settings, data=None):
            accel_string = settings.get_string("terminal-hotkey")

            k, m = Gtk.accelerator_parse(accel_string)

            store.clear()
            store.append((k, m))

        self.settings.connect("changed::terminal-hotkey", update_accel_from_settings)
        update_accel_from_settings(self.settings)

        def on_accel_changed(accel, path, key, mods, code, data=None):
            name = Gtk.accelerator_name(key, mods)
            self.settings.set_string("terminal-hotkey", name)

            cell.set_property("text", Gtk.accelerator_get_label(key, mods))

        def on_accel_cleared(accel, path, data=None):
            self.settings.set_string("terminal-hotkey", "")

        cell.connect("accel-edited", on_accel_changed)
        cell.connect("accel-cleared", on_accel_cleared)

        frame.add(treeview)

        widget = LabeledItem(_("Keyboard shortcut"), frame)
        box.pack_start(widget, False, False, 6)

        self.add_page(page, "main", _("Basic"))

        # Advanced

        page = Page()

        frame = Gtk.Frame()
        frame.get_style_context().add_class("view")

        page.add(frame)

        box = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
        frame.add(box)

        entry = Gtk.Entry()
        self.settings.bind("terminal-shell",
                           entry, "text",
                           Gio.SettingsBindFlags.DEFAULT)

        widget = LabeledItem(_("Shell to use (leave blank for system default)"), entry)
        box.pack_start(widget, False, False, 6)

        frame = Gtk.Frame()
        frame.get_style_context().add_class("view")

        page.add(frame)

        box = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
        frame.add(box)

        entry = Gtk.Entry()
        self.settings.bind("terminal-erase-line",
                           entry, "text",
                           Gio.SettingsBindFlags.DEFAULT)

        widget = LabeledItem(_("Terminal erase line key sequence"), entry)
        box.pack_start(widget, False, False, 6)

        entry = Gtk.Entry()
        self.settings.bind("terminal-restore-line",
                           entry, "text",
                           Gio.SettingsBindFlags.DEFAULT)

        widget = LabeledItem(_("Terminal restore line key sequence"), entry)
        box.pack_start(widget, False, False, 6)

        entry = Gtk.Entry()
        self.settings.bind("terminal-change-directory-command",
                           entry, "text",
                           Gio.SettingsBindFlags.DEFAULT)

        widget = LabeledItem(_("Change directory command"), entry)
        box.pack_start(widget, False, False, 6)

        box.pack_start(Gtk.Separator(orientation=Gtk.Orientation.HORIZONTAL), False, False, 6)

        button = Gtk.Button(_("Restore defaults"))
        button.set_valign(Gtk.Align.CENTER)

        def on_reset_clicked(button, data=None):
            for key in self.settings.list_keys():
                self.settings.reset(key)

        button.connect("clicked", on_reset_clicked)

        widget = LabeledItem(_("Sequences must be escaped according to python rules.") + " " +
                             _("'%s' is replaced by the quoted directory name."), button)
        widget.label_widget.set_line_wrap(True)
        widget.label_widget.set_max_width_chars(40)
        widget.label_widget.set_justify(Gtk.Justification.FILL)

        box.pack_start(widget, False, False, 6)

        self.add_page(page, "advanced", _("Advanced"))

        self.show_all()

        self.present()

    def quit(self, *args):
        self.destroy()
        Gtk.main_quit()

if __name__ == "__main__":
    import signal
    signal.signal(signal.SIGINT, signal.SIG_DFL)

    window = NemoTerminalPreferencesWindow()

    Gtk.main()



#!/usr/bin/python3
# -*- coding: utf-8 -*-
#    nemo-compare --- Context menu extension for Nemo file manager
#    Copyright (C) 2011  Guido Tabbernuk <boamaod@gmail.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.

import os
import gettext
import locale
import gi
import signal
signal.signal(signal.SIGINT, signal.SIG_DFL)

gi.require_version('Gtk', '3.0')
from gi.repository import Gtk

import utils

def combo_add_and_select(combo, text):
    '''Convenience function to add/selct item in ComboBoxEntry'''
    combo.append_text(text)
    model = combo.get_model()
    iter = model.get_iter_first()
    while model.iter_next(iter):
        iter = model.iter_next(iter)
    combo.set_active_iter(iter)

class NemoCompareExtensionPreferences:
    '''The main class for preferences dialog using PyGTK'''

    combo = None
    combo_3way = None
    combo_multi = None

    def cancel_event(self, widget, event, data = None):
        '''This callback quits the program'''
        Gtk.main_quit()
        return False

    def changed_cb(self, combo):
        '''Any of the comboboxes has changed, change the data accordingly'''
        model = combo.get_model()
        index = combo.get_active()
        entry = combo.get_child().get_text()

        selection=""

        if len(entry)>0:
            selection=entry
        elif index:
            selection=model[index][0]

        if combo is self.combo:
            self.config.diff_engine = selection
        elif combo is self.combo_3way:
            self.config.diff_engine_3way = selection
        elif combo is self.combo_multi:
            self.config.diff_engine_multi = selection

        return

    def save_event(self, widget, event, data = None):
        '''This callback saves the settings and quits the program.'''
        self.config.save()
        Gtk.main_quit()
        return False

    def __init__(self):
        '''Load config and create UI'''

        self.config = utils.NemoCompareConfig()
        self.config.load()

        # find out if some new engines have been installed
        self.config.add_missing_predefined_engines()

        # initialize i18n
        locale.setlocale(locale.LC_ALL, '')
        gettext.bindtextdomain("nemo-extensions")
        gettext.textdomain("nemo-extensions")
        _ = gettext.gettext

        self.window = Gtk.Window.new(Gtk.WindowType.TOPLEVEL)
        self.window.set_position(Gtk.WindowPosition.CENTER)
        self.window.set_icon_name("preferences-other")
        self.window.set_resizable(False)
        self.window.set_title(_("Nemo Compare"))
        self.window.connect("delete_event",self.cancel_event)
        self.window.set_border_width(15)

        main_vbox = Gtk.Box(orientation=Gtk.Orientation.VERTICAL, spacing=0)
        self.window.add(main_vbox)

        # normal diff
        frame = Gtk.Frame.new(_("Normal Diff"))
        self.combo = Gtk.ComboBoxText.new_with_entry()

        for text in self.config.engines:
            if text == self.config.diff_engine:
                combo_add_and_select(self.combo, text)
            else:
                self.combo.append_text(text)

        self.combo.connect('changed', self.changed_cb)

        frame.add(self.combo)
        main_vbox.pack_start(frame, True, True, 0)

        # 3-way diff
        frame_3way = Gtk.Frame.new(_("Three-Way Diff"))
        self.combo_3way = Gtk.ComboBoxText.new_with_entry()

        for text in self.config.engines:
            if text == self.config.diff_engine_3way:
                combo_add_and_select(self.combo_3way, text)
            else:
                self.combo_3way.append_text(text)

        self.combo_3way.connect('changed', self.changed_cb)

        frame_3way.add(self.combo_3way)
        main_vbox.pack_start(frame_3way, True, True, 0)

        # n-way diff
        frame_multi = Gtk.Frame.new(_("N-Way Diff"))
        self.combo_multi = Gtk.ComboBoxText.new_with_entry()

        for text in self.config.engines:
            if text == self.config.diff_engine_multi:
                combo_add_and_select(self.combo_multi, text)
            else:
                self.combo_multi.append_text(text)

        self.combo_multi.connect('changed', self.changed_cb)

        frame_multi.add(self.combo_multi)
        main_vbox.pack_start(frame_multi, True, True, 0)

        separator = Gtk.Separator(orientation=Gtk.Orientation.HORIZONTAL)
        main_vbox.pack_start(separator, False, True, 5)

        # cancel / ok
        confirm_hbox = Gtk.Box(orientation=Gtk.Orientation.HORIZONTAL, spacing=0)
        main_vbox.pack_start(confirm_hbox, False, False, 0)

        cancel_button = Gtk.Button(label=_("Cancel"))
        cancel_button.connect_object("clicked", self.cancel_event, self.window, None)
        confirm_hbox.pack_start(cancel_button, True, True, 5)

        ok_button = Gtk.Button(label=_("Ok"))
        ok_button.connect_object("clicked", self.save_event, self.window, None)
        confirm_hbox.pack_start(ok_button, True, True, 5)

        self.window.show_all()
        self.window.present()

    def main(self):
        '''GTK main method'''
        Gtk.main()

if __name__ == "__main__":
    prefs = NemoCompareExtensionPreferences()
    prefs.main()



#!/usr/bin/python3

from setuptools import setup

# Create data files

# Setup stage
setup( packages=[],
    name         = "nemo-audio-tab",
    version      = "6.6.0",
    description  = "View audio tag information from the file manager's properties tab",
    author       = "Linux Mint",
    author_email = "root@linuxmint.com",
    url          = "https://github.com/linuxmint/nemo-extensions",
    license      = "GPL3",

    # See debian/control for install-depends - this is useless here, except as reference.
    # install_requires (and only works with python modules.  It's equally as bad to have
    # some deps here, then draw them into debian/control using {python3:Depends} and add
    # them to our non-python depends.

    # install_requires = [
    #     'gir1.2-nemo-3.0',
    #     'gir1.2-gtk-3.0',
    #     'gir1.2-glib-2.0',
    #     'python-nemo',
    #     'python3-mutagen'
    # ]

    data_files   = [
        ('/usr/share/nemo-python/extensions', ['nemo-extension/nemo-audio-tab.py']),
        ('/usr/share/nemo-audio-tab',         ['nemo-extension/nemo-audio-tab.glade'])
    ]
)



from gi.repository import Nemo, GObject

class ExampleMenuProvider(GObject.GObject, Nemo.MenuProvider):
    def __init__(self):
        pass

    def get_file_items(self, window, files):
        top_menuitem = Nemo.MenuItem(name='ExampleMenuProvider::Foo',
                                     label='Foo',
                                     tip='',
                                     icon='')

        submenu = Nemo.Menu()
        top_menuitem.set_submenu(submenu)

        sub_menuitem = Nemo.MenuItem(name='ExampleMenuProvider::Bar',
                                     label='Bar',
                                     tip='',
                                     icon='')
        submenu.append_item(sub_menuitem)

        return top_menuitem,

    def get_background_items(self, window, file):
        submenu = Nemo.Menu()
        submenu.append_item(Nemo.MenuItem(name='ExampleMenuProvider::Bar2',
                                          label='Bar2',
                                          tip='',
                                          icon=''))

        menuitem = Nemo.MenuItem(name='ExampleMenuProvider::Foo2',
                                 label='Foo2',
                                 tip='',
                                 icon='')
        menuitem.set_submenu(submenu)

        return menuitem,



import hashlib
import urllib.parse

from gi.repository import Nemo, Gtk, GObject

class MD5SumPropertyPage(GObject.GObject, Nemo.PropertyPageProvider):
    def __init__(self):
        pass

    def get_property_pages(self, files):
        if len(files) != 1:
            return

        file = files[0]
        if file.get_uri_scheme() != 'file':
            return

        if file.is_directory():
            return

        filename = urllib.parse.unquote(file.get_uri()[7:])

        self.property_label = Gtk.Label('MD5Sum')
        self.property_label.show()

        self.hbox = Gtk.HBox(homogeneous=False, spacing=0)
        self.hbox.show()

        label = Gtk.Label('MD5Sum:')
        label.show()
        self.hbox.pack_start(label, False, False, 0)

        self.value_label = Gtk.Label()
        self.hbox.pack_start(self.value_label, False, False, 0)

        md5sum = hashlib.md5()
        with open(filename,'rb') as f:
            while chunk := f.read(8192):
                md5sum.update(chunk)

        self.value_label.set_text(md5sum.hexdigest())
        self.value_label.show()

        return Nemo.PropertyPage(name="NemoPython::md5_sum",
                                 label=self.property_label,
                                 page=self.hbox),



#!/usr/bin/python3

# Nemo Terminal

from setuptools import setup

# Setup stage
setup( packages=[],
    name         = "nemo-terminal",
    version      = "6.6.0",
    description  = "Embedded VTE terminal for Nemo file manager",
    author       = "Linux Mint",
    author_email = "root@linuxmint.com",
    url          = "https://github.com/linuxmint/nemo-extensions",
    license      = "GPL3",

    # See debian/control for install-depends - this is useless here, except as reference.
    # install_requires (and only works with python modules.  It's equally as bad to have
    # some deps here, then draw them into debian/control using {python3:Depends} and add
    # them to our non-python depends.

    # install_requires = ['python-nemo (>= 1.0)',
    #                     'gir1.2-nemo-3.0',
    #                     'gir1.2-vte-2.91',
    #                     'gir1.2-gtk-3.0 (>= 3.8.4~)',
    #                     'gir1.2-glib-2.0 (>= 1.38.0~)',
    #                     'gir1.2-xapp-1.0 (>= 3.8.0)'],

    data_files = [
        ('/usr/share/nemo-python/extensions', ['src/nemo_terminal.py']),
        ('/usr/bin',                          ['src/nemo-terminal-prefs']),
        ('/usr/share/nemo-terminal',          ['src/nemo-terminal-prefs.py',
                                               'pixmap/logo_120x120.png']),
        ('/usr/share/glib-2.0/schemas',       ['src/org.nemo.extensions.nemo-terminal.gschema.xml'])
    ]
)



#!/usr/bin/python3

# change log:
# RavetcoFX: Forked from nemo-media-columns and nemo-emblems

from urllib import parse
import locale, gettext, os
import mutagen

from gi.repository import GObject, Gio, Gtk, Nemo
# for id3 support
from mutagen.easyid3 import EasyID3
from mutagen.mp3 import MP3
from mutagen.flac import FLAC

# Import the gettext function and alias it as _
from gettext import gettext as _

class AudioPropertyPage(GObject.GObject, Nemo.PropertyPageProvider, Nemo.NameAndDescProvider):

    def get_property_pages(self, files):
        # files: list of NemoVFSFile
        if len(files) != 1:
            return []

        file = files[0]
        if file.get_uri_scheme() != 'file':
            return []

        if file.is_directory():
            return []

        if not(file.is_mime_type('audio/mpeg') or file.is_mime_type('audio/flac')):
            return []

        filename = parse.unquote(file.get_uri()[7:])

        #GUI
        locale.setlocale(locale.LC_ALL, '')
        gettext.bindtextdomain("nemo-extensions")
        gettext.textdomain("nemo-extensions")
        _ = gettext.gettext

        self.property_label = Gtk.Label(_('Audio'))
        self.property_label.show()

        self.builder = Gtk.Builder()
        self.builder.set_translation_domain('nemo-extensions')
        self.builder.add_from_file("/usr/share/nemo-audio-tab/nemo-audio-tab.glade")

        #connect gtk objects to python variables
        for obj in self.builder.get_objects():
            if issubclass(type(obj), Gtk.Buildable):
                name = Gtk.Buildable.get_name(obj)
                setattr(self, name, obj)

        # set defaults to blank to prevent nonetype errors
        file.add_string_attribute('title', '')
        file.add_string_attribute('album', '')
        file.add_string_attribute('artist', '')
        file.add_string_attribute('albumartist', '')
        file.add_string_attribute('tracknumber', '')
        file.add_string_attribute('genre', '')
        file.add_string_attribute('date', '')
        file.add_string_attribute('bitrate', '')
        file.add_string_attribute('samplerate', '')
        file.add_string_attribute('length', '')
        file.add_string_attribute('encodedby', '')
        file.add_string_attribute('copyright', '')

        no_info = _("No Info")
        mutaFile = mutagen.File(filename)

        #MP3
        if file.is_mime_type('audio/mpeg'):
            # attempt to read ID3 tag
            try:
                audio = EasyID3(filename)
                # sometimes the audio variable will not have one of these items defined, that's why
                # there is this long try / except attempt
                try: file.add_string_attribute('title', audio["title"][0])
                except: file.add_string_attribute('title', no_info)
                try: file.add_string_attribute('album', audio["album"][0])
                except: file.add_string_attribute('album', no_info)
                try: file.add_string_attribute('artist', audio["artist"][0])
                except: file.add_string_attribute('artist', no_info)
                try: file.add_string_attribute('albumartist', audio["performer"][0])
                except: file.add_string_attribute('albumartist', no_info)
                try: file.add_string_attribute('tracknumber', audio["tracknumber"][0])
                except: file.add_string_attribute('tracknumber', no_info)
                try: file.add_string_attribute('genre', audio["genre"][0])
                except: file.add_string_attribute('genre', no_info)
                try: file.add_string_attribute('date', audio["date"][0])
                except: file.add_string_attribute('date', no_info)
                try: file.add_string_attribute('encodedby', audio["encodedby"][0])
                except: file.add_string_attribute('encodedby', no_info)
                try: file.add_string_attribute('copyright', audio["copyright"][0])
                except: file.add_string_attribute('copyright', no_info)
            except:
                # [SabreWolfy] some files have no ID3 tag and will throw this exception:
                file.add_string_attribute('title', no_info)
                file.add_string_attribute('album', no_info)
                file.add_string_attribute('artist', no_info)
                file.add_string_attribute('albumartist', no_info)
                file.add_string_attribute('tracknumber', no_info)
                file.add_string_attribute('genre', no_info)
                file.add_string_attribute('date', no_info)
                file.add_string_attribute('encodedby', no_info)
                file.add_string_attribute('copyright', no_info)

                # try to read MP3 information (bitrate, length, samplerate)
            try:
                with open(filename, 'rb') as mpfile:
                    mpinfo = MP3(mpfile).info
                    file.add_string_attribute('bitrate', str(mpinfo.bitrate/1000) + " Kbps")

                    file.add_string_attribute('samplerate', str(mpinfo.sample_rate) + " Hz")
                    # [SabreWolfy] added consistent formatting of times in format hh:mm:ss
                    mp3length = "%02i:%02i:%02i" % ((int(mpinfo.length/3600)), (int(mpinfo.length/60%60)), (int(mpinfo.length%60)))
                    file.add_string_attribute('length', mp3length)
            except Exception as e:
                print(e)
                file.add_string_attribute('bitrate', no_info)
                file.add_string_attribute('length', no_info)
                file.add_string_attribute('samplerate', no_info)

        #FLAC
        if file.is_mime_type('audio/flac'):
            try:
                audio = FLAC(filename)
                # sometimes the audio variable will not have one of these items defined, that's why
                # there is this long try / except attempt
                try: file.add_string_attribute('title', audio["title"][0])
                except: file.add_string_attribute('title', no_info)
                try: file.add_string_attribute('album', audio["album"][0])
                except: file.add_string_attribute('album', no_info)
                try: file.add_string_attribute('artist', audio["artist"][0])
                except: file.add_string_attribute('artist', no_info)
                try: file.add_string_attribute('albumartist', audio["albumartist"][0]) # this tag is different then mp3s
                except: file.add_string_attribute('albumartist', no_info)
                try: file.add_string_attribute('tracknumber', audio["tracknumber"][0])
                except: file.add_string_attribute('tracknumber', no_info)
                try: file.add_string_attribute('genre', audio["genre"][0])
                except: file.add_string_attribute('genre', no_info)
                try: file.add_string_attribute('date', audio["date"][0])
                except: file.add_string_attribute('date', no_info)
                try: file.add_string_attribute('encodedby', audio["encoded-by"][0]) # this tag is different then mp3s
                except: file.add_string_attribute('encodedby', no_info)
                try: file.add_string_attribute('copyright', audio["copyright"][0])
                except: file.add_string_attribute('copyright', no_info)
            except:
                # [SabreWolfy] some files have no ID3 tag and will throw this exception:
                file.add_string_attribute('title', no_info)
                file.add_string_attribute('album', no_info)
                file.add_string_attribute('artist', no_info)
                file.add_string_attribute('albumartist', no_info)
                file.add_string_attribute('tracknumber', no_info)
                file.add_string_attribute('genre', no_info)
                file.add_string_attribute('date', no_info)
                file.add_string_attribute('encodedby', no_info)
                file.add_string_attribute('copyright', no_info)

                # try to read the FLAC information (length, samplerate)
            try:
                
                file.add_string_attribute('samplerate', (mutaFile.info.sample_rate) + " Hz")
                
                # [SabreWolfy] added consistent formatting of times in format hh:mm:ss
                flaclength = "%02i:%02i:%02i" % ((int(mutaFile.info.length/3600)), (int(mutaFile.info.length/60%60)), (int(mutaFile.info.length%60)))
                file.add_string_attribute('length', flaclength)
                flacbitrate0 = (mutaFile.info.bitrate) / 1000
                flacbitrate = f"{flacbitrate0:.3f} kbps"
                file.add_string_attribute('bitrate', flacbitrate)
            except:
                file.add_string_attribute('bitrate', no_info)
                file.add_string_attribute('length', no_info)
                file.add_string_attribute('samplerate', no_info)

        self.builder.get_object("title_text").set_label(file.get_string_attribute('title'))
        self.builder.get_object("album_text").set_label(file.get_string_attribute('album'))
        self.builder.get_object("album_artist_text").set_label(file.get_string_attribute('albumartist'))
        self.builder.get_object("artist_text").set_label(file.get_string_attribute('artist'))
        self.builder.get_object("genre_text").set_label(file.get_string_attribute('genre'))
        self.builder.get_object("year_text").set_label(file.get_string_attribute('date'))
        self.builder.get_object("track_number_text").set_label(file.get_string_attribute('tracknumber'))
        self.builder.get_object("sample_rate_text").set_label(file.get_string_attribute('samplerate'))
        self.builder.get_object("length_number").set_label(file.get_string_attribute('length'))
        self.builder.get_object("bitrate_number").set_label(file.get_string_attribute('bitrate'))
        self.builder.get_object("encoded_by_text").set_label(file.get_string_attribute('encodedby'))
        self.builder.get_object("copyright_text").set_label(file.get_string_attribute('copyright'))

        return [
            Nemo.PropertyPage(name="NemoPython::audio",
                              label=self.property_label,
                              page=self.builder_root_widget)
        ]

    def get_name_and_desc(self):
        description = _("View audio tag information from the properties tab")
        return [(f"nemo-audio-tab:::{description}")]



#!/usr/bin/python3
# -*- coding: utf-8 -*-
#    nemo-compare --- Context menu extension for Nemo file manager
#    Copyright (C) 2011  Guido Tabbernuk <boamaod@gmail.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.

import sys
import os
from urllib import parse
import gettext
import locale
import signal
from gi.repository import GLib
signal.signal(signal.SIGINT, signal.SIG_DFL)

# Import the gettext function and alias it as _
from gettext import gettext as _

import gi
gi.require_version('Nemo', '3.0')
from gi.repository import Nemo, GObject, Gio

sys.path.append("/usr/share/nemo-compare")

import utils

class NemoCompareExtension(GObject.GObject, Nemo.MenuProvider, Nemo.NameAndDescProvider):
    '''Class for the extension itself'''

    # to hold an item for later comparison
    for_later = None

    def __init__(self):
        '''Load config'''

        self.config = utils.NemoCompareConfig()
        self.config.load()

    def menu_activate_cb(self, menu, paths):
        '''Telling from amount of paths runs appropriate comparator engine'''
        if len(paths) == 1:
            self.for_later = paths[0]
            return

        cmd = None
        if len(paths) == 2:
            cmd = [self.config.diff_engine] + paths
        elif len(paths) == 3 and len(self.config.diff_engine_3way.strip()) > 0:
            cmd = [self.config.diff_engine_3way] + paths
        elif len(self.config.diff_engine_multi.strip()) > 0:
            cmd = [self.config.diff_engine_multi] + paths

        if cmd is not None:
            GLib.spawn_async(argv=cmd, flags=GLib.SpawnFlags.DEFAULT | GLib.SpawnFlags.SEARCH_PATH)

    def valid_file(self, file):
        '''Tests if the file is valid comparable'''
        if file.get_uri_scheme() == 'file' and file.get_file_type() in (Gio.FileType.DIRECTORY, Gio.FileType.REGULAR, Gio.FileType.SYMBOLIC_LINK):
            return True
        else:
            return False

    def get_file_items(self, window, files):
        '''Main method to detect what choices should be offered in the context menu'''
        paths = []
        for file in files:
            if self.valid_file(file):
                path = parse.unquote(file.get_uri()[7:])
                paths.append(path)

        # no files selected
        if len(paths) < 1:
            return

        # initialize i18n
        locale.setlocale(locale.LC_ALL, '')
        gettext.bindtextdomain("nemo-extensions")
        gettext.textdomain("nemo-extensions")
        _ = gettext.gettext

        item1 = None
        item2 = None
        item3 = None

        # for paths with remembered items
        new_paths = list(paths)

        for_later_relative = None
        if self.for_later is not None:
            if len(paths) >= 1:
                for_later_relative = os.path.relpath(self.for_later, os.path.dirname(paths[0]))
            else:
                for_later_relative = self.for_later

        # exactly one file selected
        if len(paths) == 1:

            # and one was already selected for later comparison
            if self.for_later is not None:

                # we don't want to compare file to itself
                if self.for_later not in paths:
                    item1 = Nemo.MenuItem(
                        name="NemoCompareExtension::CompareTo",
                        label=_('Compare to: ') + for_later_relative,
                        tip=_("Compare to the file previously selected")
                    )

                    # compare the one saved for later to the one selected now
                    new_paths.insert(0, self.for_later)

            # if only one file selected, we offer to remember it for later anyway
            item3 = Nemo.MenuItem(
                name="NemoCompareExtension::CompareLater",
                label=_('Compare Later'),
                tip=_("Remember file for later comparison")
            )

        # can always compare, if more than one selected
        else:
            # if we have already remembered one file and add some more, we can do n-way compare
            if self.for_later is not None:
                if self.for_later not in paths:
                    # if multi compare enabled and in case of 2 files selected 3way compare enabled
                    if len(self.config.diff_engine_multi.strip()) > 0 or (len(paths) == 2 and len(self.config.diff_engine_3way.strip()) > 0):
                        item1 = Nemo.MenuItem(
                            name="NemoCompareExtension::MultiCompare",
                            label=_('Compare to: ') + for_later_relative,
                            tip=_("Compare to the file previously selected")
                        )
                        # compare the one saved for later to the ones selected now
                        new_paths.insert(0, self.for_later)

            # if multi compare enabled, we can compare any number
            # if there are two files selected we can always compare
            # if three files selected and 3-way compare is on, we can do it
            if len(self.config.diff_engine_multi.strip()) > 0 or len(paths) == 2 or (len(paths) == 3 and len(self.config.diff_engine_3way.strip()) > 0):
                item2 = Nemo.MenuItem(
                    name="NemoCompareExtension::CompareWithin",
                    label=_('Compare'),
                    tip=_("Compare selected files")
                )

        if item1: item1.connect('activate', self.menu_activate_cb, new_paths)
        if item2: item2.connect('activate', self.menu_activate_cb, paths)
        if item3: item3.connect('activate', self.menu_activate_cb, paths)

        items = [item1, item2, item3]

        while None in items:
            items.remove(None)

        return items

    def get_background_items(self, window, item):
        return []

    def get_name_and_desc(self):
        description = _("Allows file comparison from the context menu")
        return [(f"nemo-compare:::{description}:::nemo-compare-preferences")]



import os
import urllib.parse

from gi.repository import GObject, Nemo

class ColumnExtension(GObject.GObject, Nemo.ColumnProvider, Nemo.InfoProvider):
    def __init__(self):
        pass

    def get_columns(self):
        return Nemo.Column(name="NemoPython::block_size_column",
                           attribute="block_size",
                           label="Block size",
                           description="Get the block size"),

    def update_file_info(self, file):
        if file.get_uri_scheme() != 'file':
            return

        filename = urllib.parse.unquote(file.get_uri()[7:])

        file.add_string_attribute('block_size', str(os.stat(filename).st_blksize))



#!/usr/bin/python3
# -*- coding: utf-8 -*-
#    nemo-compare --- Context menu extension for Nemo file manager
#    Copyright (C) 2011  Guido Tabbernuk <boamaod@gmail.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.

import os
import configparser
from gi.repository import GLib

APP = 'nemo-compare'

# settings
CONFIG_FILES = []
CONFIG_FILES = [os.path.join(GLib.get_user_config_dir(), APP + ".conf"), os.path.join("/etc", APP + ".conf")]
CONFIG_FILE = CONFIG_FILES[0]
SETTINGS_MAIN = 'Settings'

DIFF_PATH = 'diff_engine_path'
DIFF_PATH_3WAY = 'diff_engine_path_3way'
DIFF_PATH_MULTI = 'diff_engine_path_multi'

COMPARATORS = 'defined_comparators'
# ordered by preference
PREDEFINED_ENGINES = ['meld', 'kdiff3', 'diffuse', 'kompare', 'fldiff', 'tkdiff']
DEFAULT_DIFF_ENGINE = "meld"

# where comparator engines are sought
COMPARATOR_PATHS = ['/usr/bin', '/usr/local/bin']

class NemoCompareConfig:

    diff_engine = DEFAULT_DIFF_ENGINE
    diff_engine_3way = DEFAULT_DIFF_ENGINE
    diff_engine_multi = ""
    engines = []

    config = None

    def load(self):
        '''Loads config options if available. If not, creates them using the best heuristics availabe.'''
        self.config = configparser.ConfigParser()

        self.config['DEFAULT'] = {DIFF_PATH: 'meld',
                                  DIFF_PATH_3WAY: 'meld',
                                  DIFF_PATH_MULTI: '',
                                  COMPARATORS: 'meld'}

        # allow system-wide default settings from /etc/*
        if os.path.isfile(CONFIG_FILES[0]):
            self.config.read(CONFIG_FILES[0])
        else:
            self.config.read(CONFIG_FILES[1])

        # read from start or flush from the point where cancelled
        try:
            main = self.config[SETTINGS_MAIN]
            self.diff_engine = main[DIFF_PATH]
            self.diff_engine_3way = main[DIFF_PATH_3WAY]
            self.diff_engine_multi = main[DIFF_PATH_MULTI]
            self.engines = main[COMPARATORS].split(',')
        except KeyError:
            # maybe settings were half loaded when exception was thrown
            try:
                self.config.add_section(SETTINGS_MAIN)
            except configparser.DuplicateSectionError:
                pass

            self.add_missing_predefined_engines()

            # add choice for "engine not enabled"
            # (always needed, because at least self.engines cannot be loaded)
            self.engines.insert(0, "")

            # if default engine is not installed, replace with preferred installed engine
            if len(self.engines) > 0:
                if self.diff_engine not in self.engines:
                    self.diff_engine = self.engines[0]
                if self.diff_engine_3way not in self.engines:
                    self.diff_engine_3way = self.engines[0]
                if self.diff_engine_multi not in self.engines:
                    self.diff_engine_multi = self.engines[0]

            self.engines.sort()

            main = self.config[SETTINGS_MAIN]
            main[DIFF_PATH] = self.diff_engine
            main[DIFF_PATH_3WAY] = self.diff_engine_3way
            main[DIFF_PATH_MULTI] = self.diff_engine_multi

            strlist = ",".join(self.engines)

            main[COMPARATORS] = strlist

            with open(CONFIG_FILE, 'w') as f:
                self.config.write(f)

    def add_missing_predefined_engines(self):
        '''Adds predefined engines which are installed, but missing in engines list.'''
        system_utils = []
        for path in COMPARATOR_PATHS:
            try:
                system_utils += os.listdir(path)
            except:
                pass
        for engine in PREDEFINED_ENGINES:
            if engine not in self.engines and engine in system_utils:
                self.engines.append(engine)


    def save(self):
        '''Saves config options'''
        try:
            self.config.add_section(SETTINGS_MAIN)
        except configparser.DuplicateSectionError:
            pass

        main = self.config[SETTINGS_MAIN]
        main[DIFF_PATH] = self.diff_engine
        main[DIFF_PATH_3WAY] = self.diff_engine_3way
        main[DIFF_PATH_MULTI] = self.diff_engine_multi

        if self.diff_engine not in self.engines:
            self.engines.append(self.diff_engine)
        if self.diff_engine_3way not in self.engines:
            self.engines.append(self.diff_engine_3way)
        if self.diff_engine_multi not in self.engines:
            self.engines.append(self.diff_engine_multi)

        system_utils = []
        for path in COMPARATOR_PATHS:
            try:
                system_utils += os.listdir(path)
            except:
                pass
        for engine in self.engines:
            if engine not in system_utils:
                self.engines.remove(engine)

        strlist = ",".join(self.engines)

        main[COMPARATORS] = strlist

        with open(CONFIG_FILE, 'w') as f:
            self.config.write(f)



#!/usr/bin/python3

# Folder Color 0.0.11 - http://launchpad.net/folder-color
# Copyright (C) 2012-2014 Marcos Alvarez Costales https://launchpad.net/~costales
#
# folder-color is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# Folder Color is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Folder Color; if not, see http://www.gnu.org/licenses
# for more information.


from setuptools import setup

# Setup stage
setup( packages=[],
    name         = "nemo-emblems",
    version      = "6.6.0",
    description  = "Change your folder and file emblems",
    author       = "Linux Mint",
    author_email = "root@linuxmint.com",
    url          = "https://github.com/linuxmint/nemo-extensions",
    license      = "GPL3",

    # See debian/control for install-depends - this is useless here, except as reference.
    # install_requires (and only works with python modules.  It's equally as bad to have
    # some deps here, then draw them into debian/control using {python3:Depends} and add
    # them to our non-python depends.

    # install_requires = ['gir1.2-nemo-3.0>=3.9',
    #                     'python-nemo >=3.9'],
    data_files   = [
        ('/usr/share/nemo-python/extensions', ['nemo-extension/nemo-emblems.py'])
    ]
)



#!/usr/bin/python3
# -*- coding: utf-8 -*-
# nemo-pastebin - Nemo extension to paste a file to a pastebin service
# Written by:
#    Alessio Treglia <quadrispro@ubuntu.com>
# Copyright (C) 2009-2010, Alessio Treglia
#
# This package is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This package is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this package; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
#

from setuptools import setup

def get_app_path_files():
    return [
        'data/nemo-pastebin-configurator.ui',
        'src/nemo-pastebin-configurator.py'
    ]

data_files = [
    ('/usr/share/icons/hicolor/scalable/apps', ['data/nemo-pastebin.svg']),
    ('/usr/share/icons/hicolor/48x48/apps', ['data/nemo-pastebin.png']),
    ('/usr/share/glib-2.0/schemas', ['data/nemo-pastebin.gschema.xml']),
    ('/usr/bin', ['src/nemo-pastebin-configurator']),
    ('/usr/share/nemo-pastebin', get_app_path_files()),
    ('/usr/share/nemo-python/extensions', ['src/nemo-pastebin.py'])
]

pkg_short_dsc = "Nemo extension to send files to a pastebin"
pkg_long_dsc = """nemo-pastebin is a Nemo extension written in Python, which allows users to upload text-only files to a pastebin service just by right-clicking on them. Users can also add their favorite service just by creatine new presets."""

setup(name='nemo-pastebin', packages=[],
      version='6.6.0',
      author='Linux Mint',
      author_email='root@linuxmint.com',
      license='GPL-2',
      url='https://github.com/linuxmint/nemo-extensions',
      description=pkg_short_dsc,
      long_description=pkg_long_dsc,
      data_files=data_files
)
